@@ -9,6 +9,7 @@
 #ifdef HAVE_ORC
 #include <orc/orc.h>
 #endif
+#include <schroedinger/opengl/schroopengl.h>
 
 extern int _schro_decode_prediction_only;
 extern int _schro_dump_enable;
@@ -65,5 +66,9 @@ schro_init(void)
 #ifdef HAVE_CUDA
   schro_cuda_init ();
 #endif
+
+#ifdef HAVE_OPENGL
+  schro_opengl_init ();
+#endif
 }
 
