@@ -362,6 +362,8 @@ init_params (SchroEncoderFrame *frame)
   SchroParams *params = &frame->params;
   SchroEncoder *encoder = frame->encoder;
   SchroVideoFormat *video_format = params->video_format;
+  int shift;
+  int codeblock_size;
   int i;
 
   params->video_format = &encoder->video_format;
@@ -425,22 +427,58 @@ init_params (SchroEncoderFrame *frame)
   schro_params_calculate_mc_sizes (params);
   schro_params_calculate_iwt_sizes (params);
 
-  {
-    int shift = params->transform_depth;
-    if (encoder->enable_dc_multiquant) {
-      params->horiz_codeblocks[0] = params->iwt_luma_width >> (shift + 3);
-      params->vert_codeblocks[0] = params->iwt_luma_height >> (shift + 3);
+  codeblock_size = encoder->codeblock_size;
+  if (codeblock_size == 0) {
+    if (params->is_noarith) {
+      codeblock_size = 1;
     } else {
-      /* This is to work around a bug in the decoder that was fixed 8/2008. */
+      codeblock_size = 2;
+    }
+  }
+  switch (codeblock_size) {
+    case 1: /* small (blocks of size 5x5) */
+      shift = params->transform_depth;
+      params->horiz_codeblocks[0] = (params->iwt_luma_width >> shift) / 5;
+      params->vert_codeblocks[0] = (params->iwt_luma_height >> shift) / 5;
+      for(i=1;i<params->transform_depth+1;i++){
+        shift = params->transform_depth + 1 - i;
+        /* These values are empirically derived from fewer than 2 test results */
+        params->horiz_codeblocks[i] = (params->iwt_luma_width >> shift) / 5;
+        params->vert_codeblocks[i] = (params->iwt_luma_height >> shift) / 5;
+        SCHRO_DEBUG("codeblocks %d %d %d", i, params->horiz_codeblocks[i],
+            params->vert_codeblocks[i]);
+      }
+      break;
+    case 0:
+    default:
+    case 2: /* medium (blocks of size 8x8) */
+      shift = params->transform_depth;
+      params->horiz_codeblocks[0] = (params->iwt_luma_width >> shift) / 8;
+      params->vert_codeblocks[0] = (params->iwt_luma_height >> shift) / 8;
+      for(i=1;i<params->transform_depth+1;i++){
+        shift = params->transform_depth + 1 - i;
+        params->horiz_codeblocks[i] = (params->iwt_luma_width >> shift) / 8;
+        params->vert_codeblocks[i] = (params->iwt_luma_height >> shift) / 8;
+        SCHRO_DEBUG("codeblocks %d %d %d", i, params->horiz_codeblocks[i],
+            params->vert_codeblocks[i]);
+      }
+      break;
+    case 3: /* large (uses spec defaults) */
+      break;
+    case 4: /* full (codeblocks are entire subband) */
       params->horiz_codeblocks[0] = 1;
       params->vert_codeblocks[0] = 1;
-    }
-    for(i=1;i<params->transform_depth+1;i++){
-      shift = params->transform_depth + 1 - i;
+      for(i=1;i<params->transform_depth+1;i++){
+        params->horiz_codeblocks[i] = 1;
+        params->vert_codeblocks[i] = 1;
+      }
+      break;
+  }
 
-      params->horiz_codeblocks[i] = params->iwt_luma_width >> (shift + 3);
-      params->vert_codeblocks[i] = params->iwt_luma_height >> (shift + 3);
-    }
+  if (!encoder->enable_dc_multiquant) {
+    /* This is to work around a bug in the decoder that was fixed 8/2008. */
+    params->horiz_codeblocks[0] = 1;
+    params->vert_codeblocks[0] = 1;
   }
 
   if (frame->params.is_noarith) {
@@ -474,15 +512,25 @@ get_alloc (SchroEncoder *encoder, double requested_bits)
 {
   double x;
   double y;
+  int must_use_bits;
+  double alloc;
 
-  x = requested_bits/encoder->buffer_size;
+  must_use_bits = MAX(0, encoder->buffer_level + encoder->bits_per_picture
+      - encoder->buffer_size);
+
+  x = MAX(0, requested_bits - must_use_bits) /
+    MAX(0, encoder->buffer_size - encoder->bits_per_picture);
 
   y = 1 - exp(-x);
 
-  SCHRO_DEBUG("%g/%d -> %g", requested_bits, encoder->buffer_level,
-      encoder->buffer_level * y);
+  alloc = must_use_bits + (encoder->buffer_level - must_use_bits) * y;
 
-  return encoder->buffer_level * y;
+  SCHRO_DEBUG("request %g, level %d/%d, must use %d -> x %g y %g alloc %g",
+      requested_bits,
+      encoder->buffer_level, encoder->buffer_size,
+      must_use_bits, x, y, alloc);
+
+  return alloc;
 }
 
 /**
@@ -496,6 +544,15 @@ schro_encoder_calculate_allocation (SchroEncoderFrame *frame)
 {
   SchroEncoder *encoder = frame->encoder;
 
+  if (frame->encoder->rate_control != SCHRO_ENCODER_RATE_CONTROL_CONSTANT_BITRATE) {
+    /* FIXME this function shouldn't be called for CBR */
+
+    frame->hard_limit_bits = frame->output_buffer_size * 8;
+    frame->allocated_mc_bits = frame->hard_limit_bits;
+    frame->allocated_residual_bits = frame->hard_limit_bits;
+    return;
+  }
+
   /* FIXME should be fixed elsewhere */
   if (frame->picture_weight == 0.0) frame->picture_weight = 1.0;
 
@@ -504,6 +561,7 @@ schro_encoder_calculate_allocation (SchroEncoderFrame *frame)
     frame->allocated_residual_bits = get_alloc (encoder,
         encoder->bits_per_picture * frame->picture_weight *
         encoder->magic_allocation_scale);
+    frame->hard_limit_bits = encoder->buffer_level;
   } else {
     double weight;
 
@@ -519,6 +577,12 @@ schro_encoder_calculate_allocation (SchroEncoderFrame *frame)
     frame->allocated_residual_bits = get_alloc (encoder,
         encoder->bits_per_picture * weight *
         encoder->magic_allocation_scale);
+    frame->allocated_residual_bits -= frame->estimated_mc_bits;
+    if (frame->allocated_residual_bits < 0) {
+      SCHRO_DEBUG("allocated residual bits less than 0");
+      frame->allocated_residual_bits = 0;
+    }
+    frame->hard_limit_bits = encoder->buffer_level;
   }
 }
 
@@ -728,9 +792,9 @@ void
 schro_encoder_handle_gop_backref (SchroEncoder *encoder, int i)
 {
   SchroEncoderFrame *frame;
-  SchroEncoderFrame *f;
-  int j;
-  int gop_length;
+  SchroPictureNumber retire;
+  SchroPictureNumber ref0;
+  SchroPictureNumber ref1;
 
   frame = encoder->frame_queue->elements[i].data;
 
@@ -739,54 +803,29 @@ schro_encoder_handle_gop_backref (SchroEncoder *encoder, int i)
 
   schro_engine_check_new_sequence_header (encoder, frame);
 
-  gop_length = encoder->magic_subgroup_length;
-  SCHRO_DEBUG("handling gop from %d to %d (index %d)", encoder->gop_picture,
-      encoder->gop_picture + gop_length - 1, i);
+  //schro_engine_code_BBBP (encoder, i, 1);
+  if (frame->start_sequence_header) {
+    schro_encoder_pick_retire (frame, &retire);
 
-  if (i + gop_length >= encoder->frame_queue->n) {
-    if (encoder->end_of_stream) {
-      gop_length = encoder->frame_queue->n - i;
-    } else {
-      SCHRO_DEBUG("not enough pictures in queue");
-      return;
-    }
+    schro_engine_code_picture (frame, TRUE, retire, 0, -1, -1);
+    frame->picture_weight = encoder->magic_keyframe_weight;
+  } else {
+    schro_encoder_pick_retire (frame, &retire);
+    schro_encoder_pick_refs (frame, &ref0, &ref1);
+
+    schro_engine_code_picture (frame, TRUE, retire,
+        (ref1 == SCHRO_PICTURE_NUMBER_INVALID)?1:2, ref0, ref1);
+    frame->picture_weight = encoder->magic_inter_p_weight;
   }
-
-  for (j = 0; j < gop_length; j++) {
-    f = encoder->frame_queue->elements[i+j].data;
-
-    if (f->busy || !f->stages[SCHRO_ENCODER_FRAME_STAGE_ANALYSE].is_done) {
-      SCHRO_DEBUG("picture %d not ready", i + j);
-      return;
-    }
-
-    schro_engine_get_scene_change_score (encoder, i+j);
-
-    schro_dump (SCHRO_DUMP_SCENE_CHANGE, "%d %g %g\n",
-        f->frame_number, f->scene_change_score,
-        f->average_luma);
-
-    if (j>=1 && f->scene_change_score > encoder->magic_scene_change_threshold) {
-      /* probably a scene change.  terminate gop */
-      gop_length = j;
-    }
-  }
-
-  SCHRO_DEBUG("gop length %d", gop_length);
-
-  schro_engine_code_picture (frame, TRUE, encoder->last_ref, 0, -1, -1);
+  schro_encoder_expire_reference (encoder, frame->frame_number - 2);
   frame->presentation_frame = frame->frame_number;
-  frame->picture_weight = 1 + (gop_length - 1) * (1 - encoder->magic_inter_b_weight);
+  frame->picture_weight = 1;
   encoder->last_ref = frame->frame_number;
 
-  for (j = 1; j < gop_length; j++) {
-    f = encoder->frame_queue->elements[i+j].data;
-    schro_engine_code_picture (f, FALSE, -1, 1, frame->frame_number, -1);
-    f->presentation_frame = f->frame_number;
-    f->picture_weight = encoder->magic_inter_b_weight;
+  encoder->gop_picture += 1;
+  if (frame->start_sequence_header) {
+    schro_encoder_expire_refs_before (encoder, frame->frame_number);
   }
-
-  encoder->gop_picture += gop_length;
 }
 
 int
