@@ -6,19 +6,12 @@
 #include <liboil/liboil.h>
 #include <string.h>
 #include <schroedinger/schrooil.h>
-
-int _schro_motion_ref = FALSE;
-
-#ifdef ENABLE_MOTION_REF
-static int
-get_pixel (SchroMotion *motion, int k, SchroUpsampledFrame *upframe,
-    int x, int y, int dx, int dy);
-
-int
-schro_motion_pixel_predict_block (SchroMotion *motion, int x, int y, int k,
-    int i, int j);
+#ifdef HAVE_ORC
+#include <schroedinger/schroorc.h>
 #endif
 
+extern int _schro_motion_ref;
+
 
 SchroMotion *
 schro_motion_new (SchroParams *params, SchroUpsampledFrame *ref1,
@@ -48,148 +41,6 @@ schro_motion_free (SchroMotion *motion)
   schro_free (motion);
 }
 
-#ifdef ENABLE_MOTION_REF
-static void
-schro_motion_get_global_vector (SchroMotion *motion, int ref, int x, int y,
-    int *dx, int *dy)
-{
-  SchroParams *params = motion->params;
-  SchroGlobalMotion *gm = params->global_motion + ref;
-  int alpha, beta;
-  int scale;
-
-  alpha = gm->a_exp;
-  beta = gm->c_exp;
-
-  scale = (1<<beta) - (gm->c0 * x + gm->c1 * y);
-
-  *dx = scale * (gm->a00 * x + gm->a01 * y + (1<<alpha) * gm->b0);
-  *dy = scale * (gm->a10 * x + gm->a11 * y + (1<<alpha) * gm->b1);
-
-  *dx >>= (alpha+beta);
-  *dy >>= (alpha+beta);
-}
-
-
-static int
-schro_motion_pixel_predict (SchroMotion *motion, int x, int y, int k)
-{
-  int i,j;
-  int value;
-
-  i = (x + motion->xoffset) / motion->xbsep - 1;
-  j = (y + motion->yoffset) / motion->ybsep - 1;
-
-  value = schro_motion_pixel_predict_block (motion, x, y, k, i, j);
-  value += schro_motion_pixel_predict_block (motion, x, y, k, i + 1, j);
-  value += schro_motion_pixel_predict_block (motion, x, y, k, i, j + 1);
-  value += schro_motion_pixel_predict_block (motion, x, y, k, i + 1, j + 1);
-
-  return ROUND_SHIFT(value, 6);
-}
-
-static int
-get_dc_pixel (SchroMotion *motion, int i, int j, int k, int x, int y)
-{
-  SchroParams *params = motion->params;
-  SchroMotionVectorDC *mvdc;
-
-  mvdc = (SchroMotionVectorDC *)
-    &motion->motion_vectors[j*params->x_num_blocks + i];
-
-  return mvdc->dc[k] + 128;
-}
-
-static int
-get_ref1_pixel (SchroMotion *motion, int i, int j, int k, int x, int y)
-{
-  SchroParams *params = motion->params;
-  SchroMotionVector *mv;
-  int value;
-  int dx, dy;
-
-  mv = &motion->motion_vectors[j*params->x_num_blocks + i];
-  if (mv->using_global) {
-    schro_motion_get_global_vector (motion, 0, x, y, &dx, &dy);
-  } else {
-    dx = mv->dx[0];
-    dy = mv->dy[0];
-  }
-
-  value = (motion->ref1_weight + motion->ref2_weight) *
-      get_pixel (motion, k, motion->src1, x, y, dx, dy);
-
-  return ROUND_SHIFT(value, motion->ref_weight_precision);
-}
-
-static int
-get_ref2_pixel (SchroMotion *motion, int i, int j, int k, int x, int y)
-{
-  SchroParams *params = motion->params;
-  SchroMotionVector *mv;
-  int value;
-  int dx, dy;
-
-  mv = &motion->motion_vectors[j*params->x_num_blocks + i];
-  if (mv->using_global) {
-    schro_motion_get_global_vector (motion, 1, x, y, &dx, &dy);
-  } else {
-    dx = mv->dx[1];
-    dy = mv->dy[1];
-  }
-
-  value = (motion->ref1_weight + motion->ref2_weight) *
-      get_pixel (motion, k, motion->src2, x, y, dx, dy);
-
-  return ROUND_SHIFT(value, motion->ref_weight_precision);
-}
-
-static int
-get_biref_pixel (SchroMotion *motion, int i, int j, int k, int x, int y)
-{
-  SchroParams *params = motion->params;
-  SchroMotionVector *mv;
-  int value;
-  int dx0, dx1, dy0, dy1;
-
-  mv = &motion->motion_vectors[j*params->x_num_blocks + i];
-  if (mv->using_global) {
-    schro_motion_get_global_vector (motion, 0, x, y, &dx0, &dy0);
-    schro_motion_get_global_vector (motion, 1, x, y, &dx1, &dy1);
-  } else {
-    dx0 = mv->dx[0];
-    dy0 = mv->dy[0];
-    dx1 = mv->dx[1];
-    dy1 = mv->dy[1];
-  }
-
-  value = motion->ref1_weight *
-    get_pixel (motion, k, motion->src1, x, y, dx0, dy0);
-  value += motion->ref2_weight *
-    get_pixel (motion, k, motion->src2, x, y, dx1, dy1);
-
-  return ROUND_SHIFT(value, motion->ref_weight_precision);
-}
-
-static int
-get_pixel (SchroMotion *motion, int k, SchroUpsampledFrame *upframe,
-    int x, int y, int dx, int dy)
-{
-  int px, py;
-
-  if (k > 0) {
-    dx >>= SCHRO_CHROMA_FORMAT_H_SHIFT(motion->params->video_format->chroma_format);
-    dy >>= SCHRO_CHROMA_FORMAT_V_SHIFT(motion->params->video_format->chroma_format);
-  }
-
-  px = (x << motion->mv_precision) + dx;
-  py = (y << motion->mv_precision) + dy;
-
-  return schro_upsampled_frame_get_pixel_precN (upframe, k, px, py,
-      motion->mv_precision);
-}
-#endif
-
 static int
 get_ramp (int x, int offset)
 {
@@ -200,79 +51,6 @@ get_ramp (int x, int offset)
   return 1 + (6 * x + offset - 1)/(2*offset - 1);
 }
 
-#ifdef ENABLE_MOTION_REF
-int
-schro_motion_pixel_predict_block (SchroMotion *motion, int x, int y, int k,
-    int i, int j)
-{
-  SchroParams *params = motion->params;
-  SchroMotionVector *mv;
-  int xmin, xmax, ymin, ymax;
-  int wx, wy;
-  int value;
-  int width, height;
-
-  if (i < 0 || j < 0) return 0;
-  if (i >= params->x_num_blocks || j >= params->y_num_blocks) return 0;
-
-  width = motion->xbsep * params->x_num_blocks;
-  height = motion->ybsep * params->y_num_blocks;
-
-  xmin = i * motion->xbsep - motion->xoffset;
-  ymin = j * motion->ybsep - motion->yoffset;
-  xmax = (i+1) * motion->xbsep + motion->xoffset;
-  ymax = (j+1) * motion->ybsep + motion->yoffset;
-
-  if (x < xmin || y < ymin || x >= xmax || y >= ymax) return 0;
-
-  if (motion->xoffset == 0) {
-    wx = 8;
-  } else if (x < motion->xoffset || x >= width - motion->xoffset) {
-    wx = 8;
-  } else if (x - xmin < 2*motion->xoffset) {
-    wx = get_ramp (x - xmin, motion->xoffset);
-  } else if (xmax - 1 - x < 2*motion->xoffset) {
-    wx = get_ramp (xmax - 1 - x, motion->xoffset);
-  } else {
-    wx = 8;
-  }
-
-  if (motion->yoffset == 0) {
-    wy = 8;
-  } else if (y < motion->yoffset || y >= height - motion->yoffset) {
-    wy = 8;
-  } else if (y - ymin < 2*motion->yoffset) {
-    wy = get_ramp (y - ymin, motion->yoffset);
-  } else if (ymax - 1 - y < 2*motion->yoffset) {
-    wy = get_ramp (ymax - 1 - y, motion->yoffset);
-  } else {
-    wy = 8;
-  }
-
-  mv = &motion->motion_vectors[j*params->x_num_blocks + i];
-
-  switch (mv->pred_mode) {
-    case 0:
-      value = get_dc_pixel (motion, i, j, k, x, y);
-      break;
-    case 1:
-      value = get_ref1_pixel (motion, i, j, k, x, y);
-      break;
-    case 2:
-      value = get_ref2_pixel (motion, i, j, k, x, y);
-      break;
-    case 3:
-      value = get_biref_pixel (motion, i, j, k, x, y);
-      break;
-    default:
-      value = 0;
-      break;
-  }
-
-  return value * wx * wy;
-}
-#endif
-
 /* motion render (faster) */
 
 void
@@ -311,15 +89,14 @@ static void
 get_dc_block (SchroMotion *motion, int i, int j, int k, int x, int y)
 {
   SchroParams *params = motion->params;
-  SchroMotionVectorDC *mvdc;
+  SchroMotionVector *mv;
   int value;
   int ii, jj;
 
-  mvdc = (SchroMotionVectorDC *)
-    &motion->motion_vectors[j*params->x_num_blocks + i];
+  mv = &motion->motion_vectors[j*params->x_num_blocks + i];
 
   memcpy (&motion->block, &motion->alloc_block, sizeof(SchroFrameData));
-  value = mvdc->dc[k];
+  value = mv->u.dc.dc[k];
   for(jj=0;jj<motion->yblen;jj++) {
     uint8_t *data = SCHRO_FRAME_DATA_GET_LINE (&motion->block, jj);
     /* FIXME splat */
@@ -341,7 +118,7 @@ get_ref1_block (SchroMotion *motion, int i, int j, int k, int x, int y)
   mv = &motion->motion_vectors[j*params->x_num_blocks + i];
   SCHRO_ASSERT (mv->using_global == FALSE);
 
-  get_block (motion, k, 0, i, j, mv->dx[0], mv->dy[0]);
+  get_block (motion, k, 0, i, j, mv->u.vec.dx[0], mv->u.vec.dy[0]);
 
   weight = motion->ref1_weight + motion->ref2_weight;
   shift = motion->ref_weight_precision;
@@ -374,7 +151,7 @@ get_ref2_block (SchroMotion *motion, int i, int j, int k, int x, int y)
   mv = &motion->motion_vectors[j*params->x_num_blocks + i];
   SCHRO_ASSERT (mv->using_global == FALSE);
 
-  get_block (motion, k, 1, i, j, mv->dx[1], mv->dy[1]);
+  get_block (motion, k, 1, i, j, mv->u.vec.dx[1], mv->u.vec.dy[1]);
 
   weight = motion->ref1_weight + motion->ref2_weight;
   shift = motion->ref_weight_precision;
@@ -407,8 +184,8 @@ get_biref_block (SchroMotion *motion, int i, int j, int k, int x, int y)
   mv = &motion->motion_vectors[j*params->x_num_blocks + i];
   SCHRO_ASSERT (mv->using_global == FALSE);
 
-  get_block (motion, k, 0, i, j, mv->dx[0], mv->dy[0]);
-  get_block (motion, k, 1, i, j, mv->dx[1], mv->dy[1]);
+  get_block (motion, k, 0, i, j, mv->u.vec.dx[0], mv->u.vec.dy[0]);
+  get_block (motion, k, 1, i, j, mv->u.vec.dx[1], mv->u.vec.dy[1]);
 
   weight0 = motion->ref1_weight;
   weight1 = motion->ref2_weight;
@@ -564,12 +341,20 @@ schro_motion_block_accumulate (SchroMotion *motion, SchroFrameData *comp,
       break;
     default:
       for(j=0;j<motion->yblen;j++) {
+#ifdef HAVE_ORC
+        orc_multiply_and_add_s16_u8 (
+            SCHRO_FRAME_DATA_GET_PIXEL_S16 (comp, x, y + j),
+            SCHRO_FRAME_DATA_GET_LINE (&motion->obmc_weight, j),
+            SCHRO_FRAME_DATA_GET_LINE (&motion->block, j),
+            motion->xblen);
+#else
         oil_multiply_and_add_s16_u8 (
             SCHRO_FRAME_DATA_GET_PIXEL_S16 (comp, x, y + j),
             SCHRO_FRAME_DATA_GET_PIXEL_S16 (comp, x, y + j),
             SCHRO_FRAME_DATA_GET_LINE (&motion->obmc_weight, j),
             SCHRO_FRAME_DATA_GET_LINE (&motion->block, j),
             motion->xblen);
+#endif
       }
       break;
   }
@@ -667,7 +452,9 @@ schro_motion_render (SchroMotion *motion, SchroFrame *dest)
   SchroParams *params = motion->params;
   int max_x_blocks;
   int max_y_blocks;
+#ifndef HAVE_ORC
   int16_t zero = 0;
+#endif
 
 #ifdef ENABLE_MOTION_REF
   if (_schro_motion_ref) {
@@ -676,6 +463,11 @@ schro_motion_render (SchroMotion *motion, SchroFrame *dest)
   }
 #endif
 
+  if (schro_motion_render_fast_allowed (motion)) {
+    schro_motion_render_fast (motion, dest);
+    return;
+  }
+
   if (params->have_global_motion) {
 #ifdef ENABLE_MOTION_REF
     SCHRO_WARNING ("global motion enabled, using reference motion renderer");
@@ -770,8 +562,13 @@ schro_motion_render (SchroMotion *motion, SchroFrame *dest)
     schro_motion_init_obmc_weight (motion);
 
     for(j=0;j<comp->height;j++){
+#ifdef HAVE_ORC
+      orc_splat_s16_ns (SCHRO_FRAME_DATA_GET_LINE(comp, j), 0,
+          comp->width);
+#else
       oil_splat_s16_ns (SCHRO_FRAME_DATA_GET_LINE(comp, j), &zero,
           comp->width);
+#endif
     }
 
     max_x_blocks = MIN(params->x_num_blocks - 1,
@@ -824,6 +621,9 @@ schro_motion_render (SchroMotion *motion, SchroFrame *dest)
 
 
     for(j=0;j<comp->height;j++){
+#ifdef HAVE_ORC
+      orc_rrshift6_s16_ip (SCHRO_FRAME_DATA_GET_LINE(comp, j), motion->width);
+#else
       int16_t as[2] = { 1, 1 };
 
       as[1] = 6;
@@ -831,6 +631,7 @@ schro_motion_render (SchroMotion *motion, SchroFrame *dest)
 
       oil_add_const_rshift_s16 (SCHRO_FRAME_DATA_GET_LINE(comp, j),
           SCHRO_FRAME_DATA_GET_LINE(comp, j), as, motion->width);
+#endif
     }
 
     schro_free (motion->alloc_block.data);
@@ -849,7 +650,7 @@ schro_motion_render (SchroMotion *motion, SchroFrame *dest)
 void
 schro_motion_dc_prediction (SchroMotion *motion, int x, int y, int *pred)
 {
-  SchroMotionVectorDC *mvdc;
+  SchroMotionVector *mv;
   int i;
 
   for(i=0;i<3;i++){
@@ -857,23 +658,23 @@ schro_motion_dc_prediction (SchroMotion *motion, int x, int y, int *pred)
     int n = 0;
 
     if (x>0) {
-      mvdc = SCHRO_MOTION_GET_DC_BLOCK(motion,x-1,y);
-      if (mvdc->pred_mode == 0) {
-        sum += mvdc->dc[i];
+      mv = SCHRO_MOTION_GET_BLOCK(motion,x-1,y);
+      if (mv->pred_mode == 0) {
+        sum += mv->u.dc.dc[i];
         n++;
       }
     }
     if (y>0) {
-      mvdc = SCHRO_MOTION_GET_DC_BLOCK(motion,x,y-1);
-      if (mvdc->pred_mode == 0) {
-        sum += mvdc->dc[i];
+      mv = SCHRO_MOTION_GET_BLOCK(motion,x,y-1);
+      if (mv->pred_mode == 0) {
+        sum += mv->u.dc.dc[i];
         n++;
       }
     }
     if (x>0 && y>0) {
-      mvdc = SCHRO_MOTION_GET_DC_BLOCK(motion,x-1,y-1);
-      if (mvdc->pred_mode == 0) {
-        sum += mvdc->dc[i];
+      mv = SCHRO_MOTION_GET_BLOCK(motion,x-1,y-1);
+      if (mv->pred_mode == 0) {
+        sum += mv->u.dc.dc[i];
         n++;
       }
     }
@@ -888,7 +689,7 @@ schro_motion_dc_prediction (SchroMotion *motion, int x, int y, int *pred)
         pred[i] = (sum+1)>>1;
         break;
       case 3:
-        pred[i] = schro_divide(sum + 1,3);
+        pred[i] = schro_divide3(sum + 1);
         break;
       default:
         SCHRO_ASSERT(0);
@@ -953,24 +754,24 @@ schro_motion_vector_prediction (SchroMotion *motion,
   if (x>0) {
     mv = SCHRO_MOTION_GET_BLOCK(motion,x-1,y);
     if (mv->using_global == FALSE && (mv->pred_mode & mode)) {
-      vx[n] = mv->dx[mode-1];
-      vy[n] = mv->dy[mode-1];
+      vx[n] = mv->u.vec.dx[mode-1];
+      vy[n] = mv->u.vec.dy[mode-1];
       n++;
     }
   }
   if (y>0) {
     mv = SCHRO_MOTION_GET_BLOCK(motion,x,y-1);
     if (mv->using_global == FALSE && (mv->pred_mode & mode)) {
-      vx[n] = mv->dx[mode-1];
-      vy[n] = mv->dy[mode-1];
+      vx[n] = mv->u.vec.dx[mode-1];
+      vy[n] = mv->u.vec.dy[mode-1];
       n++;
     }
   }
   if (x>0 && y>0) {
     mv = SCHRO_MOTION_GET_BLOCK(motion,x-1,y-1);
     if (mv->using_global == FALSE && (mv->pred_mode & mode)) {
-      vx[n] = mv->dx[mode-1];
-      vy[n] = mv->dy[mode-1];
+      vx[n] = mv->u.vec.dx[mode-1];
+      vy[n] = mv->u.vec.dy[mode-1];
       n++;
     }
   }
@@ -1111,14 +912,13 @@ schro_motion_verify (SchroMotion *motion)
       switch (mv->pred_mode) {
         case 0:
           {
-            SchroMotionVectorDC *mvdc = (SchroMotionVectorDC *)mv;
             int i;
 
             for(i=0;i<3;i++){
               /* FIXME 8bit */
-              if (mvdc->dc[i] < -128 || mvdc->dc[i] > 127) {
+              if (mv->u.dc.dc[i] < -128 || mv->u.dc.dc[i] > 127) {
                 SCHRO_ERROR("mv(%d,%d) has bad DC value [%d] %d", x, y,
-                    i, mvdc->dc[i]);
+                    i, mv->u.dc.dc[i]);
                 return 0;
               }
             }
@@ -1147,57 +947,4 @@ schro_motion_verify (SchroMotion *motion)
   return 1;
 }
 
-#ifdef ENABLE_MOTION_REF
-void
-schro_motion_render_ref (SchroMotion *motion, SchroFrame *dest)
-{
-  SchroParams *params = motion->params;
-  int k;
-  int x,y;
-  int16_t *line;
-
-  if (params->num_refs == 1) {
-    SCHRO_ASSERT(params->picture_weight_2 == 1);
-  }
-
-  motion->ref_weight_precision = params->picture_weight_bits;
-  motion->ref1_weight = params->picture_weight_1;
-  motion->ref2_weight = params->picture_weight_2;
-
-  motion->mv_precision = params->mv_precision;
-
-  for(k=0;k<3;k++){
-    SchroFrameData *comp = dest->components + k;
-
-    if (k == 0) {
-      motion->xbsep = params->xbsep_luma;
-      motion->ybsep = params->ybsep_luma;
-      motion->xblen = params->xblen_luma;
-      motion->yblen = params->yblen_luma;
-    } else {
-      motion->xbsep = params->xbsep_luma >>
-        SCHRO_CHROMA_FORMAT_H_SHIFT(motion->params->video_format->chroma_format);
-      motion->ybsep = params->ybsep_luma >>
-        SCHRO_CHROMA_FORMAT_V_SHIFT(motion->params->video_format->chroma_format);
-      motion->xblen = params->xblen_luma >>
-        SCHRO_CHROMA_FORMAT_H_SHIFT(motion->params->video_format->chroma_format);
-      motion->yblen = params->yblen_luma >>
-        SCHRO_CHROMA_FORMAT_V_SHIFT(motion->params->video_format->chroma_format);
-    }
-    motion->xoffset = (motion->xblen - motion->xbsep)/2;
-    motion->yoffset = (motion->yblen - motion->ybsep)/2;
-
-    for(y=0;y<comp->height;y++){
-      line = SCHRO_FRAME_DATA_GET_LINE(comp, y);
-      for(x=0;x<comp->width;x++){
-        line[x] = CLAMP(schro_motion_pixel_predict (motion, x, y, k), 0, 255);
-
-        /* Note: the 128 offset converts the 0-255 range of the reference
-         * pictures into the bipolar range used for Dirac signal processing */
-        line[x] -= 128;
-      }
-    }
-  }
-}
-#endif
 
