@@ -174,10 +174,18 @@ copy (SchroFrame *frame, void *_dest, int component, int i)
   src = schro_virt_frame_get_line (frame, component, i);
   switch (SCHRO_FRAME_FORMAT_DEPTH(frame->format)) {
     case SCHRO_FRAME_FORMAT_DEPTH_U8:
+#ifdef HAVE_ORC
+      orc_memcpy (dest, src, frame->components[component].width);
+#else
       oil_memcpy (dest, src, frame->components[component].width);
+#endif
       break;
     case SCHRO_FRAME_FORMAT_DEPTH_S16:
+#ifdef HAVE_ORC
+      orc_memcpy (dest, src, frame->components[component].width * 2);
+#else
       oil_memcpy (dest, src, frame->components[component].width * 2);
+#endif
       break;
     default:
       SCHRO_ASSERT(0);
@@ -568,25 +576,39 @@ unpack_yuyv (SchroFrame *frame, void *_dest, int component, int i)
 {
   uint8_t *dest = _dest;
   uint8_t *src;
+#ifndef HAVE_ORC
   int j;
+#endif
 
   src = schro_virt_frame_get_line (frame->virt_frame1, 0, i);
 
   switch (component) {
     case 0:
+#ifdef HAVE_ORC
+      orc_unpack_yuyv_y (dest, (void *)src, frame->width);
+#else
       for(j=0;j<frame->width;j++){
         dest[j] = src[j*2];
       }
+#endif
       break;
     case 1:
+#ifdef HAVE_ORC
+      orc_unpack_yuyv_u (dest, (void *)src, frame->width/2);
+#else
       for(j=0;j<frame->width/2;j++){
         dest[j] = src[j*4 + 1];
       }
+#endif
       break;
     case 2:
+#ifdef HAVE_ORC
+      orc_unpack_yuyv_v (dest, (void *)src, frame->width/2);
+#else
       for(j=0;j<frame->width/2;j++){
         dest[j] = src[j*4 + 3];
       }
+#endif
   }
 }
 
@@ -595,25 +617,39 @@ unpack_uyvy (SchroFrame *frame, void *_dest, int component, int i)
 {
   uint8_t *dest = _dest;
   uint8_t *src;
+#ifndef HAVE_ORC
   int j;
+#endif
 
   src = schro_virt_frame_get_line (frame->virt_frame1, 0, i);
 
   switch (component) {
     case 0:
+#ifdef HAVE_ORC
+      orc_unpack_uyvy_y (dest, (void *)src, frame->width);
+#else
       for(j=0;j<frame->width;j++){
         dest[j] = src[j*2 + 1];
       }
+#endif
       break;
     case 1:
+#ifdef HAVE_ORC
+      orc_unpack_uyvy_u (dest, (void *)src, frame->width/2);
+#else
       for(j=0;j<frame->width/2;j++){
         dest[j] = src[j*4 + 0];
       }
+#endif
       break;
     case 2:
+#ifdef HAVE_ORC
+      orc_unpack_uyvy_v (dest, (void *)src, frame->width/2);
+#else
       for(j=0;j<frame->width/2;j++){
         dest[j] = src[j*4 + 2];
       }
+#endif
   }
 }
 
@@ -798,7 +834,11 @@ pack_yuyv (SchroFrame *frame, void *_dest, int component, int i)
   src_u = schro_virt_frame_get_line (frame->virt_frame1, 1, i);
   src_v = schro_virt_frame_get_line (frame->virt_frame1, 2, i);
 
+#ifdef HAVE_ORC
+  orc_packyuyv (dest, src_y, src_u, src_v, frame->width/2);
+#else
   oil_packyuyv (dest, src_y, src_u, src_v, frame->width/2);
+#endif
 }
 
 
@@ -1219,7 +1259,11 @@ convert_444_422 (SchroFrame *frame, void *_dest, int component, int i)
   src = schro_virt_frame_get_line (frame->virt_frame1, component, i);
 
   if (component == 0) {
+#ifdef HAVE_ORC
+    orc_memcpy (dest, src, frame->width);
+#else
     oil_memcpy (dest, src, frame->width);
+#endif
   } else {
     for(j=0;j<frame->components[component].width;j++){
       dest[j] = src[j*2];
@@ -1236,7 +1280,11 @@ convert_444_420 (SchroFrame *frame, void *_dest, int component, int i)
 
   if (component == 0) {
     src = schro_virt_frame_get_line (frame->virt_frame1, component, i);
+#ifdef HAVE_ORC
+    orc_memcpy (dest, src, frame->components[component].width);
+#else
     oil_memcpy (dest, src, frame->components[component].width);
+#endif
   } else {
     src = schro_virt_frame_get_line (frame->virt_frame1, component, i*2);
     for(j=0;j<frame->components[component].width;j++){
@@ -1256,7 +1304,11 @@ convert_422_420 (SchroFrame *frame, void *_dest, int component, int i)
   } else {
     src = schro_virt_frame_get_line (frame->virt_frame1, component, i*2);
   }
+#ifdef HAVE_ORC
+  orc_memcpy (dest, src, frame->components[component].width);
+#else
   oil_memcpy (dest, src, frame->components[component].width);
+#endif
 }
 
 /* up */
@@ -1271,7 +1323,11 @@ convert_422_444 (SchroFrame *frame, void *_dest, int component, int i)
   src = schro_virt_frame_get_line (frame->virt_frame1, component, i);
 
   if (component == 0) {
+#ifdef HAVE_ORC
+    orc_memcpy (dest, src, frame->width);
+#else
     oil_memcpy (dest, src, frame->width);
+#endif
   } else {
     for(j=0;j<frame->components[component].width;j++){
       dest[j] = src[j>>1];
@@ -1288,7 +1344,11 @@ convert_420_444 (SchroFrame *frame, void *_dest, int component, int i)
 
   if (component == 0) {
     src = schro_virt_frame_get_line (frame->virt_frame1, component, i);
+#ifdef HAVE_ORC
+    orc_memcpy (dest, src, frame->components[component].width);
+#else
     oil_memcpy (dest, src, frame->components[component].width);
+#endif
   } else {
     src = schro_virt_frame_get_line (frame->virt_frame1, component, i>>1);
     for(j=0;j<frame->components[component].width;j++){
@@ -1308,7 +1368,11 @@ convert_420_422 (SchroFrame *frame, void *_dest, int component, int i)
   } else {
     src = schro_virt_frame_get_line (frame->virt_frame1, component, i>>1);
   }
+#ifdef HAVE_ORC
+  orc_memcpy (dest, src, frame->components[component].width);
+#else
   oil_memcpy (dest, src, frame->components[component].width);
+#endif
 }
 
 SchroFrame *
@@ -1465,13 +1529,19 @@ convert_u8_s16 (SchroFrame *frame, void *_dest, int component, int i)
 {
   uint8_t *dest = _dest;
   int16_t *src;
+#ifndef HAVE_ORC
   int16_t c = 128;
+#endif
 
   src = schro_virt_frame_get_line (frame->virt_frame1, component, i);
+#ifdef HAVE_ORC
+  orc_offsetconvert_u8_s16 (dest, src, frame->components[component].width);
+#else
   oil_addc_s16 (frame->virt_priv, src, &c,
       frame->components[component].width);
   oil_convert_u8_s16 (dest, frame->virt_priv,
       frame->components[component].width);
+#endif
 }
 
 SchroFrame *
@@ -1495,12 +1565,18 @@ convert_s16_u8 (SchroFrame *frame, void *_dest, int component, int i)
 {
   int16_t *dest = _dest;
   uint8_t *src;
+#ifndef HAVE_ORC
   int16_t c = -128;
+#endif
 
   src = schro_virt_frame_get_line (frame->virt_frame1, component, i);
 
+#ifdef HAVE_ORC
+  orc_offsetconvert_s16_u8 (dest, src, frame->components[component].width);
+#else
   oil_convert_s16_u8 (dest, src, frame->components[component].width);
   oil_addc_s16 (dest, dest, &c, frame->components[component].width);
+#endif
 }
 
 SchroFrame *
@@ -1525,7 +1601,11 @@ crop_u8 (SchroFrame *frame, void *_dest, int component, int i)
   uint8_t *src;
 
   src = schro_virt_frame_get_line (frame->virt_frame1, component, i);
+#ifdef HAVE_ORC
+  orc_memcpy (dest, src, frame->components[component].width);
+#else
   oil_memcpy (dest, src, frame->components[component].width);
+#endif
 }
 
 static void
@@ -1535,7 +1615,11 @@ crop_s16 (SchroFrame *frame, void *_dest, int component, int i)
   int16_t *src;
 
   src = schro_virt_frame_get_line (frame->virt_frame1, component, i);
+#ifdef HAVE_ORC
+  orc_memcpy (dest, src, frame->components[component].width * sizeof(int16_t));
+#else
   oil_memcpy (dest, src, frame->components[component].width * sizeof(int16_t));
+#endif
 }
 
 SchroFrame *
@@ -1574,11 +1658,19 @@ edge_extend_u8 (SchroFrame *frame, void *_dest, int component, int i)
 
   src = schro_virt_frame_get_line (frame->virt_frame1, component,
       MIN(i,srcframe->components[component].height-1));
+#ifdef HAVE_ORC
+  orc_memcpy (dest, src, srcframe->components[component].width);
+  orc_splat_u8_ns (dest + srcframe->components[component].width,
+      dest[srcframe->components[component].width - 1],
+      frame->components[component].width -
+      srcframe->components[component].width);
+#else
   oil_memcpy (dest, src, srcframe->components[component].width);
   oil_splat_u8_ns (dest + srcframe->components[component].width,
       dest + srcframe->components[component].width - 1,
       frame->components[component].width -
       srcframe->components[component].width);
+#endif
 }
 
 static void
@@ -1590,12 +1682,21 @@ edge_extend_s16 (SchroFrame *frame, void *_dest, int component, int i)
 
   src = schro_virt_frame_get_line (frame->virt_frame1, component,
       MIN(i,srcframe->components[component].height-1));
+#ifdef HAVE_ORC
+  orc_memcpy (dest, src,
+      srcframe->components[component].width * sizeof(int16_t));
+  orc_splat_s16_ns (dest + srcframe->components[component].width,
+      dest[srcframe->components[component].width - 1],
+      frame->components[component].width -
+      srcframe->components[component].width);
+#else
   oil_memcpy (dest, src,
       srcframe->components[component].width * sizeof(int16_t));
   oil_splat_s16_ns (dest + srcframe->components[component].width,
       dest + srcframe->components[component].width - 1,
       frame->components[component].width -
       srcframe->components[component].width);
+#endif
 }
 
 SchroFrame *
