@@ -12,7 +12,7 @@
  * schro_split_ext_desl93:
  * @hi: array of even components / high subband components
  * @lo: array of odd components / low subband components
- * @n: number of 
+ * @n: number of
  *
  * Performs an in-place Deslauries 9,3 wavelet transformation on
  * the arrays @hi and @lo containing the even and odd components
@@ -24,7 +24,6 @@ void
 schro_split_ext_desl93 (int16_t *hi, int16_t *lo, int n)
 {
   static const int16_t stage1_weights[] = { 1, -9, -9, 1 };
-  //static const int16_t stage2_weights[] = { 1, 1 };
   static const int16_t stage1_offset_shift[] = { 7, 4 };
   static const int16_t stage2_offset_shift[] = { 2, 2 };
 
@@ -36,28 +35,23 @@ schro_split_ext_desl93 (int16_t *hi, int16_t *lo, int n)
 
   lo[-1] = lo[0];
 
-  //oil_mas2_add_s16 (hi, hi, lo - 1, stage2_weights, stage2_offset_shift, n);
   oil_add2_rshift_add_s16 (hi, hi, lo - 1, lo, stage2_offset_shift, n);
 }
 
 void
 schro_split_ext_53 (int16_t *hi, int16_t *lo, int n)
 {
-  //static const int16_t stage1_weights[] = { -1, -1 };
-  //static const int16_t stage2_weights[] = { 1, 1 };
   static const int16_t stage1_offset_shift[] = { 1, 1 };
   static const int16_t stage2_offset_shift[] = { 2, 2 };
 
   hi[-1] = hi[0];
   hi[n] = hi[n-1];
 
-  //oil_mas2_add_s16 (lo, lo, hi, stage1_weights, stage1_offset_shift, n);
   oil_add2_rshift_sub_s16 (lo, lo, hi, hi+1, stage1_offset_shift, n);
 
   lo[-1] = lo[0];
   lo[n] = lo[n-1];
 
-  //oil_mas2_add_s16 (hi, hi, lo - 1, stage2_weights, stage2_offset_shift, n);
   oil_add2_rshift_add_s16 (hi, hi, lo - 1, lo, stage2_offset_shift, n);
 }
 
@@ -159,7 +153,6 @@ schro_split_ext_daub97 (int16_t *hi, int16_t *lo, int n)
 void
 schro_synth_ext_desl93 (int16_t *hi, int16_t *lo, int n)
 {
-  //static const int16_t stage1_weights[] = { -1, -1 };
   static const int16_t stage2_weights[] = { -1, 9, 9, -1 };
   static const int16_t stage1_offset_shift[] = { 2, 2 };
   static const int16_t stage2_offset_shift[] = { 8, 4 };
@@ -169,7 +162,6 @@ schro_synth_ext_desl93 (int16_t *hi, int16_t *lo, int n)
   lo[n] = lo[n-1];
   lo[n+1] = lo[n-1];
 
-  //oil_mas2_add_s16 (hi, hi, lo - 1, stage1_weights, stage1_offset_shift, n);
   oil_add2_rshift_sub_s16 (hi, hi, lo - 1, lo, stage1_offset_shift, n);
 
   hi[-2] = hi[0];
@@ -183,21 +175,17 @@ schro_synth_ext_desl93 (int16_t *hi, int16_t *lo, int n)
 void
 schro_synth_ext_53 (int16_t *hi, int16_t *lo, int n)
 {
-  //static const int16_t stage1_weights[] = { -1, -1 };
-  //static const int16_t stage2_weights[] = { 1, 1 };
   static const int16_t stage1_offset_shift[] = { 2, 2 };
   static const int16_t stage2_offset_shift[] = { 1, 1 };
 
   lo[-1] = lo[0];
   lo[n] = lo[n-1];
 
-  //oil_mas2_add_s16 (hi, hi, lo - 1, stage1_weights, stage1_offset_shift, n);
   oil_add2_rshift_sub_s16 (hi, hi, lo - 1, lo, stage1_offset_shift, n);
 
   hi[-1] = hi[0];
   hi[n] = hi[n-1];
 
-  //oil_mas2_add_s16 (lo, lo, hi, stage2_weights, stage2_offset_shift, n);
   oil_add2_rshift_add_s16 (lo, lo, hi, hi+1, stage2_offset_shift, n);
 }
 
@@ -303,7 +291,7 @@ void schro_iwt_desl_9_3 (int16_t *data, int stride, int width, int height,
 #define ROW(row) ((int16_t *)OFFSET(data, (row)*stride))
 
   /* FIXME */
-  SCHRO_ASSERT(height>=6);
+  SCHRO_ASSERT(height>=8);
 
   for(i=0;i<height + 6;i++){
     int i1 = i-4;
@@ -348,29 +336,15 @@ void schro_iwt_desl_9_3 (int16_t *data, int stride, int width, int height,
     if ((i2&1) == 0 && i2>=0 && i2 < height) {
       static const int16_t stage2_offset_shift[] = { 2, 2 };
       if (i2 == 0) {
-        //static const int16_t stage2_weights[] = { 1, 1 };
         oil_add2_rshift_add_s16 (
             OFFSET(data,i2*stride), OFFSET(data, i2*stride),
             OFFSET(data, (i2+1)*stride), OFFSET(data, (i2+1)*stride),
             stage2_offset_shift, width);
-#if 0
-        oil_mas2_across_add_s16 (
-            OFFSET(data,i2*stride), OFFSET(data, i2*stride),
-            OFFSET(data, (i2+1)*stride), OFFSET(data, (i2+1)*stride),
-            stage2_weights, stage2_offset_shift, width);
-#endif
       } else {
-        //static const int16_t stage2_weights[] = { 1, 1 };
         oil_add2_rshift_add_s16 (
             OFFSET(data,i2*stride), OFFSET(data, i2*stride),
             OFFSET(data, (i2-1)*stride), OFFSET(data, (i2+1)*stride),
             stage2_offset_shift, width);
-#if 0
-        oil_mas2_across_add_s16 (
-            OFFSET(data,i2*stride), OFFSET(data, i2*stride),
-            OFFSET(data, (i2-1)*stride), OFFSET(data, (i2+1)*stride),
-            stage2_weights, stage2_offset_shift, width);
-#endif
       }
     }
   }
@@ -379,8 +353,6 @@ void schro_iwt_desl_9_3 (int16_t *data, int stride, int width, int height,
 void schro_iwt_5_3 (int16_t *data, int stride, int width, int height,
     int16_t *tmp)
 {
-  //static const int16_t stage1_weights[] = { -1, -1 };
-  //static const int16_t stage2_weights[] = { 1, 1 };
   static const int16_t stage1_offset_shift[] = { 1, 1 };
   static const int16_t stage2_offset_shift[] = { 2, 2 };
   int i;
@@ -411,14 +383,6 @@ void schro_iwt_5_3 (int16_t *data, int stride, int width, int height,
           OFFSET(data, (i-2)*stride),
           d,
           stage1_offset_shift, width);
-#if 0
-      oil_mas2_across_add_s16 (
-          OFFSET(data, (i-1)*stride),
-          OFFSET(data, (i-1)*stride),
-          OFFSET(data, (i-2)*stride),
-          d,
-          stage1_weights, stage1_offset_shift, width);
-#endif
 
       if (i-3>=0) {
         d = OFFSET(data, (i-3)*stride);
@@ -431,14 +395,6 @@ void schro_iwt_5_3 (int16_t *data, int stride, int width, int height,
           d,
           OFFSET(data, (i-1)*stride),
           stage2_offset_shift, width);
-#if 0
-      oil_mas2_across_add_s16 (
-          OFFSET(data, (i-2)*stride),
-          OFFSET(data, (i-2)*stride),
-          d,
-          OFFSET(data, (i-1)*stride),
-          stage2_weights, stage2_offset_shift, width);
-#endif
     }
   }
 #undef ROW
@@ -451,7 +407,7 @@ void schro_iwt_13_5 (int16_t *data, int stride, int width, int height,
   int16_t one = 1;
 
   /* FIXME */
-  SCHRO_ASSERT(height>=6);
+  SCHRO_ASSERT(height>=8);
 
 #define ROW(row) ((int16_t *)OFFSET(data, (row)*stride))
   for(i=0;i<height + 8;i++){
@@ -753,7 +709,7 @@ void schro_iiwt_desl_9_3 (int16_t *data, int stride, int width, int height,
 #define ROW(row) ((int16_t *)OFFSET(data, (row)*stride))
 
   /* FIXME */
-  SCHRO_ASSERT(height>=6);
+  SCHRO_ASSERT(height>=8);
 
   for(i=-6;i<height;i++){
     int i1 = i+2;
@@ -761,29 +717,15 @@ void schro_iiwt_desl_9_3 (int16_t *data, int stride, int width, int height,
     if ((i2&1) == 0 && i2>=0 && i2 < height) {
       static const int16_t stage2_offset_shift[] = { 2, 2 };
       if (i2 == 0) {
-        //static const int16_t stage2_weights[] = { -1, -1 };
         oil_add2_rshift_sub_s16 (
             OFFSET(data,i2*stride), OFFSET(data, i2*stride),
             OFFSET(data, (i2+1)*stride), OFFSET(data, (i2+1)*stride),
             stage2_offset_shift, width);
-#if 0
-        oil_mas2_across_add_s16 (
-            OFFSET(data,i2*stride), OFFSET(data, i2*stride),
-            OFFSET(data, (i2+1)*stride), OFFSET(data, (i2+1)*stride),
-            stage2_weights, stage2_offset_shift, width);
-#endif
       } else {
-        //static const int16_t stage2_weights[] = { -1, -1 };
         oil_add2_rshift_sub_s16 (
             OFFSET(data,i2*stride), OFFSET(data, i2*stride),
             OFFSET(data, (i2-1)*stride), OFFSET(data, (i2+1)*stride),
             stage2_offset_shift, width);
-#if 0
-        oil_mas2_across_add_s16 (
-            OFFSET(data,i2*stride), OFFSET(data, i2*stride),
-            OFFSET(data, (i2-1)*stride), OFFSET(data, (i2+1)*stride),
-            stage2_weights, stage2_offset_shift, width);
-#endif
       }
     }
     if ((i1&1) == 0 && i1>=0 && i1 < height) {
@@ -830,8 +772,6 @@ void schro_iiwt_desl_9_3 (int16_t *data, int stride, int width, int height,
 void schro_iiwt_5_3 (int16_t *data, int stride, int width, int height,
     int16_t *tmp)
 {
-  //static const int16_t stage1_weights[] = { 1, 1 };
-  //static const int16_t stage2_weights[] = { -1, -1 };
   static const int16_t stage1_offset_shift[] = { 1, 1 };
   static const int16_t stage2_offset_shift[] = { 2, 2 };
   int i;
@@ -854,14 +794,6 @@ void schro_iiwt_5_3 (int16_t *data, int stride, int width, int height,
           d,
           OFFSET(data, (i2+1)*stride),
           stage2_offset_shift, width);
-#if 0
-      oil_mas2_across_add_s16 (
-          OFFSET(data, i2*stride),
-          OFFSET(data, i2*stride),
-          d,
-          OFFSET(data, (i2+1)*stride),
-          stage2_weights, stage2_offset_shift, width);
-#endif
     }
     if ((i1&1) == 0 && i1 >= 0 && i1 < height) {
       int16_t *d;
@@ -876,15 +808,7 @@ void schro_iiwt_5_3 (int16_t *data, int stride, int width, int height,
           OFFSET(data, i1*stride),
           d,
           stage1_offset_shift, width);
-#if 0
-      oil_mas2_across_add_s16 (
-          OFFSET(data, (i1+1)*stride),
-          OFFSET(data, (i1+1)*stride),
-          OFFSET(data, i1*stride),
-          d,
-          stage1_weights, stage1_offset_shift, width);
-#endif
-    } 
+    }
     if (i >=0 && i < height) {
       int16_t *hi = tmp + 2;
       int16_t *lo = tmp + 6 + width/2;
@@ -905,7 +829,7 @@ void schro_iiwt_13_5 (int16_t *data, int stride, int width, int height,
   int i;
 
   /* FIXME */
-  SCHRO_ASSERT(height>=6);
+  SCHRO_ASSERT(height>=8);
 
 #define ROW(row) ((int16_t *)OFFSET(data, (row)*stride))
   for(i=-8;i<height;i++){
@@ -982,7 +906,7 @@ schro_iiwt_haar (int16_t *data, int stride, int width, int height,
   int i;
   int j;
   int16_t as[2];
-  
+
   as[0] = (1<<shift)>>1;
   as[1] = shift;
 
